using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;

namespace RussellMason.Web.UI
{

	public class ControlFinder
	{

		#region Static Methods

		/// <summary>
		/// Finds a control with the specified ID within the provided control. This differs
		/// from Control.FindControl which only looks in the current naming container. This
		/// recursively searches child controls through different naming containers. It is 
		/// therefore assumed that IDs are unique accross naming containers, if not the first
		/// control found with the ID is returned.
		/// </summary>
		/// <param name="control">
		/// The control to start the search from.
		/// </param>
		/// <param name="id">
		/// The ID of the control to find.
		/// </param>
		/// <returns>
		/// The control if available; otherwise null.
		/// </returns>
		public static Control FindUniqueControl(Control control, string id)
		{
			Control foundControl = FindUniqueControlRecursive(control, id);

			return foundControl;
		} 

		#endregion Static Methods

		#region Static Implementation Methods

		/// <summary>
		/// Recursively searches child controls through different naming containers to find a 
		/// control with the specified ID.
		/// </summary>
		/// <param name="control">
		/// The control to search.
		/// </param>
		/// <param name="id">
		/// The ID of the control to find.
		/// </param>
		/// <returns>
		/// The control if available; otherwise null.
		/// </returns>
		protected static Control FindUniqueControlRecursive(Control control, string id)
		{
			Control foundControl = null;

			if (control.ID == id)
			{
				foundControl = control;
			}
			else
			{
				foreach (Control childControl in control.Controls)
				{
					foundControl = FindUniqueControl(childControl, id);

					if (foundControl != null)
					{
						break;
					}
				}
			}

			return foundControl;
		} 

		#endregion Static Implementation Methods

		#region Contructors

		/// <summary>
		/// Allows derived classes to initialize a new instance of the ControlFinder class.
		/// </summary>
		protected ControlFinder()
		{
		} 

		#endregion Contructors

	}

}
