using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;

using Telerik.WebControls;

namespace RussellMason.Web.UI.Office2007
{

	/// <summary>
	/// Base page for containing Ribbon controls.
	/// </summary>
	public class RibbonPage : StateTracePage
	{

		#region Fields

		private RadAjaxManager _ajaxManager = null; 

		#endregion Fields

		#region Constructors

		/// <summary>
		/// Initializes a new instance of the RibbonPage page.
		/// </summary>
		public RibbonPage()
		{
		} 

		#endregion Constructors

		#region Properties

		/// <summary>
		/// Gets a manager for supplying AJAX services.
		/// </summary>
		[
		DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)
		]
		public virtual RadAjaxManager AjaxManager
		{
			get
			{
				if (_ajaxManager == null)
				{
					_ajaxManager = new RadAjaxManager();
					_ajaxManager.ID = "RibbonPageAjaxManager";

					this.Form.Controls.Add(_ajaxManager);
				}

				return _ajaxManager;
			}
		} 

		#endregion MyRegion

		#region Implementation Methods

		/// <summary>
		/// Calls additional configuration methods when the page loads.
		/// </summary>
		/// <param name="e">
		/// The event data.
		/// </param>
		protected override void OnLoad(EventArgs e)
		{
			base.OnLoad(e);

			ConfigureRibbonControls();
			RegisterAjaxSettings();
		}

		/// <summary>
		/// Allows additional Ribbon controls to be added or configured.
		/// </summary>
		protected virtual void ConfigureRibbonControls()
		{
		}

		/// <summary>
		/// Allows AJAX based controls to be associated with the manager via the AjaxManager 
		/// property.
		/// </summary>
		protected virtual void RegisterAjaxSettings()
		{
		}

		/// <summary>
		/// Saves the current state of Ribbon controls to a sesion state variable called
		/// 'RibbonState'. N.B. By default this method is not called, you must call it 
		/// when required. 
		/// </summary>
		protected virtual void SaveRibbonStateToPersistenceMedium()
		{
			string xml = RibbonSerializer.Default.Serialize(this);

			this.Session["RibbonState"] = xml;
		}

		/// <summary>
		/// Restores the state of Ribbon controls from a sesion state variable called
		/// 'RibbonState'. N.B. By default this method is not called, you must call it 
		/// when required. 
		/// </summary>
		protected virtual void LoadRibbonStateFromPersistenceMedium()
		{
			string xml = this.Session["RibbonState"] as string;

			if (!string.IsNullOrEmpty(xml))
			{
				RibbonSerializer.Default.Deserialize(this, xml);
			}
		}

		#endregion Implementation Methods

	}

}
